# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.update_model_task_rules_job_spec import UpdateModelTaskRulesJobSpec

class TestUpdateModelTaskRulesJobSpec(unittest.TestCase):
    """UpdateModelTaskRulesJobSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateModelTaskRulesJobSpec:
        """Test UpdateModelTaskRulesJobSpec
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateModelTaskRulesJobSpec`
        """
        model = UpdateModelTaskRulesJobSpec()
        if include_optional:
            return UpdateModelTaskRulesJobSpec(
                job_type = 'update_model_task_rules',
                scope_model_id = '',
                rules_to_enable = [
                    ''
                    ],
                rules_to_disable = [
                    ''
                    ],
                rules_to_archive = [
                    ''
                    ],
                rules_to_add = [
                    arthur_client.api_bindings.models.new_rule_request.NewRuleRequest(
                        name = '', 
                        type = '', 
                        apply_to_prompt = True, 
                        apply_to_response = True, 
                        config = null, )
                    ]
            )
        else:
            return UpdateModelTaskRulesJobSpec(
                scope_model_id = '',
        )
        """

    def testUpdateModelTaskRulesJobSpec(self):
        """Test UpdateModelTaskRulesJobSpec"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
